==> haskell-test-framework-smallcheck-0.2-319-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-EU6uSxGOfA5IXjj4qW8NaC
key:                  test-framework-smallcheck-0.2-EU6uSxGOfA5IXjj4qW8NaC
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  256af262649ff536f26f1979749d329a
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-smallcheck
hs-libraries:         HStest-framework-smallcheck-0.2-EU6uSxGOfA5IXjj4qW8NaC
depends:
    base-4.17.2.1 smallcheck-1.2.1.1-25tnw4WijOx4OXz2KI4L28
    test-framework-0.8.2.2-KgR41U2LlpcHoPKtOjhgl0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-smallcheck-0.2-320-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-9HyosY1GOYvLQS0L12Xdk3
key:                  test-framework-smallcheck-0.2-9HyosY1GOYvLQS0L12Xdk3
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  d35eb755547955fa043b482cdbd90ac2
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-smallcheck
hs-libraries:         HStest-framework-smallcheck-0.2-9HyosY1GOYvLQS0L12Xdk3
depends:
    base-4.17.2.1 smallcheck-1.2.1.1-l0HyjvmGsICiBuoyx0XcD
    test-framework-0.8.2.2-CsPmy4wECSwGMFIJZsOfZP transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
